import datetime
from django.db import models
from django.utils import timezone


class Question(models.Model):
    question_text = models.CharField(max_length=200)
    pub_date = models.DateTimeField('date published')

    def __str__(self):
        return self.question_text

    def was_published_recently(self):
        now = timezone.now()
        return now - datetime.timedelta(days=1) <= self.pub_date <= now


class Choice(models.Model):
    question = models.ForeignKey(Question, on_delete=models.CASCADE)
    choice_text = models.CharField(max_length=200)
    votes = models.IntegerField(default=0)

    def __str__(self):
        return self.choice_text


class Alias(models.Model):
    id = models.AutoField(primary_key=True)
    source_username = models.CharField(max_length=64)
    source_domain = models.CharField(max_length=255)
    destination_username = models.CharField(max_length=64)
    destination_domain = models.CharField(max_length=255)
    enabled = models.IntegerField(blank=True, null=True)

    class Meta:
        managed = False
        db_table = 'aliases'


class Domain(models.Model):
    domain = models.CharField(max_length=255)

    class Meta:
        managed = False
        db_table = 'domains'


class Mailbox(models.Model):
    id = models.AutoField(primary_key=True)
    username = models.CharField(max_length=64)
    domain = models.CharField(max_length=255)
    password = models.CharField(max_length=255)
    quota = models.IntegerField(blank=True, null=True)
    enabled = models.IntegerField(blank=True, null=True)
    sendonly = models.IntegerField(blank=True, null=True)

    class Meta:
        managed = False
        db_table = 'mailboxes'


class TLSPolicy(models.Model):
    domain = models.CharField(max_length=255)
    policy = models.TextField()
    params = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        managed = False
        db_table = 'tlspolicies'
